@@ -247,6 +247,12 @@ def create_app(handler, username, password):
     def payoffer(msg):
         return handler.handle_pay_offer(msg)
 
+    @app.route("/decryptsqueak", methods=["POST"])
+    @login_required
+    @protobuf_serialized(squeak_admin_pb2.DecryptSqueakRequest())
+    def decryptsqueak(msg):
+        return handler.handle_decrypt_squeak(msg)
+
     @app.route("/getbuyoffers", methods=["POST"])
     @login_required
     @protobuf_serialized(squeak_admin_pb2.GetBuyOffersRequest())
@@ -529,18 +535,6 @@ def create_app(handler, username, password):
     def getsellprice(msg):
         return handler.handle_get_sell_price(msg)
 
-    @app.route("/settwitterbearertoken", methods=["POST"])
-    @login_required
-    @protobuf_serialized(squeak_admin_pb2.SetTwitterBearerTokenRequest())
-    def settwitterbearertoken(msg):
-        return handler.handle_set_twitter_bearer_token(msg)
-
-    @app.route("/gettwitterbearertoken", methods=["POST"])
-    @login_required
-    @protobuf_serialized(squeak_admin_pb2.GetTwitterBearerTokenRequest())
-    def gettwitterbearertoken(msg):
-        return handler.handle_get_twitter_bearer_token(msg)
-
     @app.route("/addtwitteraccount", methods=["POST"])
     @login_required
     @protobuf_serialized(squeak_admin_pb2.AddTwitterAccountRequest())
@@ -559,12 +553,6 @@ def create_app(handler, username, password):
     def deletetwitteraccount(msg):
         return handler.handle_delete_twitter_account(msg)
 
-    @app.route("/gettwitterstreamstatus", methods=["POST"])
-    @login_required
-    @protobuf_serialized(squeak_admin_pb2.GetTwitterStreamStatusRequest())
-    def gettwitterstreamstatus(msg):
-        return handler.handle_get_twitter_stream_status(msg)
-
     return app
 
 
